Citing xemc3
============

If you are using xemc3 for a scientific publication, please cite the code, preferably using the DOI of the version you used.

Entries for e.g. bibtex are available from `zenodo <https://zenodo.org/record/5562266>`_.

The DOI for all versions is: `DOI: 10.5281/zenodo.5562265 <https://doi.org/10.5281/zenodo.5562265>`_
